@@ -4,12 +4,16 @@ RCSID ("$Id: datatypes.c,v 1.26 2000/01/27 11:38:15 misiek Exp $")
 
      int verbose = 1;
 
+     char *filenameprefix = 0;
+
      char *httpviewer = "lynx";
      char *ftpviewer = "lynx";
      char *maileditor = "mail";
      char *printutility = "lpr";
      char *manlinks = "1:8:2:3:4:5:6:7:9:n:l:p:o:3X11:3Xt:3X:3x";
+     char *configuredinfopath = "/usr/info:/usr/share/info:/usr/local/info";
      char *ignoredmacros = 0;
+     char *rcfile = NULL;
 
      char *tmpfilename1 = 0;
      char *tmpfilename2 = 0;
@@ -36,6 +40,7 @@ RCSID ("$Id: datatypes.c,v 1.26 2000/01/27 11:38:15 misiek Exp $")
      int ConfirmQuit = 0;
      int QuitConfirmDefault = 0;
      int ClearScreenAtExit = 0;
+     int CallReadlineHistory = 1;
 
      InfoHistory infohistory;
 
@@ -43,10 +48,13 @@ RCSID ("$Id: datatypes.c,v 1.26 2000/01/27 11:38:15 misiek Exp $")
      int ncursor = -1;
      int nmenu = -1;
      int use_apropos = 0;
+     int plain_apropos = 0;
      int use_manual = 0;
      int use_raw_filename = 0;
      int quote_ignored = 0;
 
+     int winchanged = 0;
+
      void
        inithistory ()
 {
@@ -149,3 +157,13 @@ dellastinfohistory ()		/* Delete last history entry */
 	}
     }
 }
+
+void
+clearfilenameprefix ()
+{
+  if (filenameprefix)
+    {
+      xfree (filenameprefix);
+      filenameprefix = 0;
+    }
+}
