@@ -135,7 +135,8 @@ dirpage_lookup (char **type, char ***message, long *lines,
 				      *first_node = xmalloc (strlen (tmp) + 1);
 				      strcpy ((*first_node), tmp);
 				    }
-				  fclose (id);	/* we don't need dirfile/badly matched infofile open anymore */
+				  if(id)
+  				    fclose (id);	/* we don't need dirfile/badly matched infofile open anymore */
 				  id = 0;
 				  if (!strstr (file, ".info"))
 				    strcat (file, ".info");
@@ -401,7 +402,8 @@ seek_indirect (FILE * id)
   return 1;
 }
 int
-seek_tag_table (FILE * id)
+seek_tag_table (FILE * id,int quiet)	/* second arg for dumping out
+					   verbose debug info or not :) */
 {
   int finito = 0;
   long seek_pos;
@@ -417,14 +419,17 @@ seek_tag_table (FILE * id)
 	{
 	  if (input == EOF)
 	    {
-	      if (!curses_open)
-		printf (_ ("Warning: could not find tag table\n"));
-	      else
-		{
-		  attrset (bottomline);
-		  mvhline (maxy - 1, 0, ' ', maxx);
-		  mvaddstr (maxy - 1, 0, _ ("Warning: could not find tag table"));
-		  attrset (normal);
+	      if(!quiet)
+	        {
+  	          if (!curses_open)
+	  	    printf (_ ("Warning: could not find tag table\n"));
+	          else
+		    {
+		      attrset (bottomline);
+		      mvhline (maxy - 1, 0, ' ', maxx);
+		      mvaddstr (maxy - 1, 0, _ ("Warning: could not find tag table"));
+		      attrset (normal);
+		    }
 		}
 	      if (type)
 		{
