@@ -27,7 +27,7 @@ void read_item (FILE * id, char **type, char ***buf, long *lines);
  * empty.
  */
 int seek_indirect (FILE * id);	/* searches for indirect entry of info file */
-int seek_tag_table (FILE * id);	/* as above, but with tag table entry */
+int seek_tag_table (FILE * id,int quiet);	/* as above, but with tag table entry */
 void load_indirect (char **message, long lines);
  /* 
   * loads indirect table (from a special node, stored in message, of lines 
