@@ -90,11 +90,10 @@ calculate_len (char *start, char *end)	/*
 void
 freelinks ()			/* frees space allocated previously by node-links */
 {
-  if (hyperobjects)
-    {
-      xfree (hyperobjects);
-      hyperobjects = 0;
-    }
+  int i;
+  if ((hyperobjects)&&(hyperobjectcount))
+    xfree (hyperobjects);
+  hyperobjects = 0;
   hyperobjectcount = 0;
 }
 
@@ -136,8 +135,8 @@ finddot (char *str, int note)	/*
 	return 0;
       ptr++;
     }
-  end[0] = strchr (str, '.');	/* nodename entry may end with dot, comma */
-  end[1] = strchr (str, ',');	/* tabulation, or newline */
+  end[0] = strrchr (str, '.');	/* nodename entry may end with dot, comma */
+  end[1] = strrchr (str, ',');	/* tabulation, or newline */
   if (!note)
     {
       end[2] = strchr (str, '\t');
@@ -368,7 +367,7 @@ initializelinks (char *line1, char *line2, int line)
 * Scan for menu references of form                                            *
 * "* Comment:[spaces](infofile)reference."                                    *
 ******************************************************************************/
-      else if ((tmp = strstr (line1, ":")) != NULL)
+      else if ((tmp = strrchr (line1, ':')) != NULL)
 	{
 	  char *start = 0, *end = 0, *dot = 0;
 	  dot = finddot (tmp + 1, MENU_DOT);	/* find the trailing dot */
