@@ -144,7 +144,9 @@ construct_manualname (char *buf, int which)	/* construct man name; take
 {
   if (!manuallinks[which].carry)
     {
-      strcpy (buf, manuallinks[which].name);
+    /* workaround for names starting with '(' */
+      if (manuallinks[which].name[0] == '(') strcpy(buf, manuallinks[which].name + 1);
+      else strcpy (buf, manuallinks[which].name);
       return;
     }
   else
@@ -157,8 +159,9 @@ construct_manualname (char *buf, int which)	/* construct man name; take
 	  strcpy (base, manual[manuallinks[which].line - 1]);
 	  strip_manual (base);
 	  ptr = base + strlen (base) - 3;
-	  while (((isalpha (*ptr)) || (*ptr == '.')) && (ptr > base))
+	  while (((isalpha (*ptr)) || (*ptr == '.') || (*ptr == '_')) && (ptr > base))
 	    ptr--;
+    if (*ptr == '(') ptr++; /* workaround for man pages with leading '(' see svgalib man pages */
 	  strcpy (buf, ptr);
 	  tmppos = strlen (buf);
 	  if (tmppos > 1);
@@ -1610,7 +1613,7 @@ add_highlights ()		/* add hyperobject highlights */
 #define TestCh tmpstr[ltlinelen]
 		      if (ltlinelen > 2)	/* skip \n, -, and the at least one char... */
 			ltlinelen -= 3;
-		      while ((isalpha (TestCh)) || (TestCh == '.'))	/* positon ltlinelen to the beginning of the link to be highlighted */
+		      while ((isalpha (TestCh)) || (TestCh == '.') || (TestCh == '_'))	/* positon ltlinelen to the beginning of the link to be highlighted */
 			ltlinelen--;
 
 		      *newlinemark = 0;
