@@ -1,6 +1,8 @@
 #ifndef __MENU_AND_NOTE_UTILS_H
 #define __MENU_AND_NOTE_UTILS_H
 
+#define ERRNODE "ERR@!#$$@#!%%^#@!OR"
+
 int ismenu (const char *line);	/* checks whether a line contains menu */
 int isnote (char *line, char *nline);	/* checks whether a line
 					   contains note */
@@ -13,6 +15,8 @@ void getprevnode (char *type, char *node);	/* gets prevnode token from top
 						   line */
 void getupnode (char *type, char *node);	/* gets the up node token from top 
 						   line */
+void getnodename (char *type, char *node);	/* reads the nodename from top
+						   line */
 void freeindirect ();
 void freetagtable ();
 #endif
