@@ -507,6 +507,21 @@ parse_line (char *line)
 	    return 1;
 	}
     }
+  else if (!strncmp (temp, "CALL-READLINE-HISTORY", 21))
+    {
+      temp = strtok (NULL, "=");
+      if (temp)
+	{
+	  if (!(temp = str_toupper (skip_whitespace (temp))))
+	    return 1;
+	  if (!strncmp (temp, "TRUE", 4))
+	    CallReadlineHistory = 1;
+	  else if (!strncmp (temp, "FALSE", 5))
+	    CallReadlineHistory = 0;
+	  else
+	    return 1;
+	}
+    }
   else if (!strncmp (temp, "CUT-EMPTY-MAN-LINES", 19))
     {
       temp = strtok (NULL, "=");
