@@ -273,7 +273,7 @@ RCSID (PKG_VER "$Id: pinfo.c,v 1.36 2000/08/27 19:09:48 pborys Exp $")
     }
 
 
-  if (seek_tag_table (id) != 2)	/* load tag table if such exists... */
+  if (seek_tag_table (id,1) != 2)	/* load tag table if such exists... */
     {
       if (ForceManualTagTable == 0)
 	{
@@ -294,11 +294,11 @@ RCSID (PKG_VER "$Id: pinfo.c,v 1.36 2000/08/27 19:09:48 pborys Exp $")
   else
     /* ...otherwise try to create one */
     {
-      if (verbose)
+      if ((verbose)&&(strcmp(curfile,"dir")))
 	printf (_ ("Warning: tag table not found...\n"));
       if (!DontHandleWithoutTagTable)
 	{
-	  if (verbose)
+	  if ((verbose)&&(strcmp(curfile,"dir")))
 	    printf (_ ("Trying to create alternate tag table...\n"));
 	  create_tag_table (id);
 	  if (TagTableEntries < 1)	/* if there weren't found any info
@@ -410,7 +410,7 @@ RCSID (PKG_VER "$Id: pinfo.c,v 1.36 2000/08/27 19:09:48 pborys Exp $")
 			  load_indirect (message, lines);	/* initialize indirect entries */
 			}
 		      freetagtable ();	/* free old tag table */
-		      if (seek_tag_table (id) != 2)	/* search for the new tagtable */
+		      if (seek_tag_table (id,0) != 2)	/* search for the new tagtable */
 			{
 			  if (ForceManualTagTable == 0)		/* if no manual initialization requested, load the tag table */
 			    {
