@@ -3,7 +3,7 @@
 
 RCSID ("$Id: video.c,v 1.17 2000/01/27 11:38:16 misiek Exp $")
 
-     void info_add_highlights (int pos, int cursor, long lines, char **message);
+     void info_add_highlights (int pos, int cursor, long lines, int column, char **message);
 
      void
        substitutestr (char *src, char *dest, char *from, char *to)
@@ -29,10 +29,11 @@ RCSID ("$Id: video.c,v 1.17 2000/01/27 11:38:16 misiek Exp $")
 }
 
 void
-addtopline (char *type)
+addtopline (char *type, int column)
 {
   char *buf1 = xmalloc (strlen (type) + 50);
   char *buf2 = xmalloc (strlen (type) + 50);
+  int buf2len;
   strcpy (buf1, type);
 
   substitutestr (buf1, buf2, "File:", _ ("File:"));
@@ -42,16 +43,18 @@ addtopline (char *type)
   substitutestr (buf1, buf2, "Up:", _ ("Up:"));
   attrset (topline);
   mymvhline (0, 0, ' ', maxx);	/* pads line with spaces -- estetic */
-  if (strlen (buf2))
-    buf2[strlen (buf2) - 1] = '\0';
-  mvaddstr (0, 0, buf2);
+  buf2len=strlen(buf2);
+  if (buf2len)
+    buf2[buf2len - 1] = '\0';
+  if(buf2len>column)
+  mvaddstr (0, 0, buf2+column);
   attrset (normal);
   xfree (buf1);
   xfree (buf2);
 }
 
 void
-showscreen (char **message, char *type, long lines, long pos, long cursor)
+showscreen (char **message, char *type, long lines, long pos, long cursor, int column)
 {
   long i;
 #ifdef getmaxyx
@@ -65,7 +68,10 @@ showscreen (char **message, char *type, long lines, long pos, long cursor)
     {
       int tmp = strlen (message[i]) - 1;
       message[i][tmp] = 0;
-      mvaddstr (i + 1 - pos, 0, message[i]);
+      if(tmp>column)
+        mvaddstr (i + 1 - pos, 0, message[i]+column);
+      else
+        move(i + 1 - pos,0);
 #ifdef HAVE_BKGDSET
       clrtoeol ();
 #else
@@ -84,13 +90,25 @@ showscreen (char **message, char *type, long lines, long pos, long cursor)
     printw (_ ("Viewing line %d/%d, %d%%"), pos + maxy - 2, lines, ((pos + maxy - 2) * 100) / lines);
   else
     printw (_ ("Viewing line %d/%d, 100%%"), lines, lines);
-  info_add_highlights (pos, cursor, lines, message);
+  info_add_highlights (pos, cursor, lines, column, message);
   attrset (normal);
   move (0, 0);
   refresh ();
 }
+
+void info_addstr(int y, int x, char *txt, int column, int txtlen)
+	/* prints a line, taking care for the horizontal scrolling.
+	   if the string fits in the window, it is drawn. If not,
+	   it is either cut, or completely ommited. */
+{
+  if(x>column)
+    mvaddstr(y,x-column,txt);
+  else if(x+txtlen>column)
+    mvaddstr(y,0,txt+(column-x));
+}
+
 void
-info_add_highlights (int pos, int cursor, long lines, char **message)
+info_add_highlights (int pos, int cursor, long lines, int column, char **message)
 {
   int i, j;
   for (i = 0; i < hyperobjectcount; i++)
@@ -129,37 +147,47 @@ info_add_highlights (int pos, int cursor, long lines, char **message)
 	    {
 	      if (hyperobjects[i].breakpos == -1)
 		{
-		  mvaddstr (1 + hyperobjects[i].line - pos,
+		  info_addstr (1 + hyperobjects[i].line - pos,
 			    hyperobjects[i].col,
-			    hyperobjects[i].node);
+			    hyperobjects[i].node,
+			    column,
+			    hyperobjects[i].nodelen);
+	          
 		}
 	      else
 		{
 		  char tmp = hyperobjects[i].node[hyperobjects[i].breakpos];
 		  hyperobjects[i].node[hyperobjects[i].breakpos] = 0;
-		  mvaddstr (1 + hyperobjects[i].line - pos,
+		  info_addstr (1 + hyperobjects[i].line - pos,
 			    hyperobjects[i].col,
-			    hyperobjects[i].node);
+			    hyperobjects[i].node,
+			    column,
+			    hyperobjects[i].breakpos);
 		  hyperobjects[i].node[hyperobjects[i].breakpos] = tmp;
 		  j = hyperobjects[i].breakpos;
 		  while (hyperobjects[i].node[j] == ' ')
 		    j++;	/* skip leading spaces after newline */
 		  if (hyperobjects[i].line - pos + 3 < maxy)
-		    mvaddstr (1 + hyperobjects[i].line - pos + 1,
+		    info_addstr (1 + hyperobjects[i].line - pos + 1,
 			      j - hyperobjects[i].breakpos,
-			      hyperobjects[i].node + j);
+			      hyperobjects[i].node + j,
+			      column,
+			      hyperobjects[i].nodelen-j);
 		}
 	    }
 	  else
 	    {
 	      if (hyperobjects[i].breakpos == -1)
 		{
-		  move (1 + hyperobjects[i].line - pos,
-			hyperobjects[i].col);
-		  addstr ("(");
-		  addstr (hyperobjects[i].file);
-		  addstr (")");
-		  addstr (hyperobjects[i].node);
+		  char *buf=xmalloc(hyperobjects[i].filelen+hyperobjects[i].nodelen+3);
+		  snprintf (buf,hyperobjects[i].filelen+hyperobjects[i].nodelen+3,
+		            "(%s)%s",hyperobjects[i].file,hyperobjects[i].node);
+		  info_addstr (1 + hyperobjects[i].line - pos,
+			hyperobjects[i].col,
+			buf,
+			column,
+			hyperobjects[i].filelen+hyperobjects[i].nodelen+2);
+		  xfree(buf);
 		}
 	      else
 		{
@@ -171,17 +199,21 @@ info_add_highlights (int pos, int cursor, long lines, char **message)
 		  strcat (buf, hyperobjects[i].node);
 		  tmp = buf[hyperobjects[i].breakpos];
 		  buf[hyperobjects[i].breakpos] = 0;
-		  mvaddstr (1 + hyperobjects[i].line - pos,
+		  info_addstr (1 + hyperobjects[i].line - pos,
 			    hyperobjects[i].col,
-			    buf);
+			    buf,
+			    column,
+			    hyperobjects[i].breakpos+2);
 		  buf[hyperobjects[i].breakpos] = tmp;
 		  j = hyperobjects[i].breakpos;
 		  while (buf[j] == ' ')
 		    j++;	/* skip leading spaces after newline */
 		  if (hyperobjects[i].line - pos + 3 < maxy)
-		    mvaddstr (1 + hyperobjects[i].line - pos + 1,
+		    info_addstr (1 + hyperobjects[i].line - pos + 1,
 			      j - hyperobjects[i].breakpos,
-			      buf + j);
+			      buf + j,
+			      column,
+			      hyperobjects[i].filelen+hyperobjects[i].nodelen+2-j);
 		}
 	    }
 	  attrset (normal);
