@@ -1,7 +1,8 @@
 
 #ifndef __VIDEO_H
 #define __VIDEO_H
-void showscreen (char **message, char *type, long lines, long pos, long cursor);
+void showscreen (char **message, char *type, long lines, long pos,
+		 long cursor, int column);
 						   /* the above paints the 
 						      screen while viewing 
 						      info file */
@@ -17,6 +18,6 @@ void mvaddstr_note (int y, int x, char *line, char *nline, int linenumber);
 void mvaddstr_note_selected (int y, int x, char *line, char *nline, int linenumber);
 						   /* prints selected note
 						      option */
-void addtopline (char *type);	/* adds top line of info 
-				   page */
+void addtopline (char *type, int column);	/* adds top line of info 
+						   page */
 #endif
